==> ppl_1.0.orig.tar.xz: ppl-user-c-interface-1.0-html/annotated.js <==
var annotated =
[
    [ "Parma_Polyhedra_Library", null, [
      [ "IO_Operators", null, null ],
      [ "CO_Tree", null, null ],
      [ "Linear_Expression_Interface", null, null ],
      [ "Linear_Expression_Impl", null, null ],
      [ "Implementation", null, null ]
    ] ],
    [ "std", null, null ],
    [ "ppl_Artificial_Parameter_Sequence_const_iterator_tag", "interfaceppl__Artificial__Parameter__Sequence__const__iterator__tag.html", "interfaceppl__Artificial__Parameter__Sequence__const__iterator__tag" ],
    [ "ppl_Artificial_Parameter_tag", "interfaceppl__Artificial__Parameter__tag.html", "interfaceppl__Artificial__Parameter__tag" ],
    [ "ppl_Coefficient_tag", "interfaceppl__Coefficient__tag.html", "interfaceppl__Coefficient__tag" ],
    [ "ppl_Congruence_System_const_iterator_tag", "interfaceppl__Congruence__System__const__iterator__tag.html", "interfaceppl__Congruence__System__const__iterator__tag" ],
    [ "ppl_Congruence_System_tag", "interfaceppl__Congruence__System__tag.html", "interfaceppl__Congruence__System__tag" ],
    [ "ppl_Congruence_tag", "interfaceppl__Congruence__tag.html", "interfaceppl__Congruence__tag" ],
    [ "ppl_Constraint_System_const_iterator_tag", "interfaceppl__Constraint__System__const__iterator__tag.html", "interfaceppl__Constraint__System__const__iterator__tag" ],
    [ "ppl_Constraint_System_tag", "interfaceppl__Constraint__System__tag.html", "interfaceppl__Constraint__System__tag" ],
    [ "ppl_Constraint_tag", "interfaceppl__Constraint__tag.html", "interfaceppl__Constraint__tag" ],
    [ "ppl_Generator_System_const_iterator_tag", "interfaceppl__Generator__System__const__iterator__tag.html", "interfaceppl__Generator__System__const__iterator__tag" ],
    [ "ppl_Generator_System_tag", "interfaceppl__Generator__System__tag.html", "interfaceppl__Generator__System__tag" ],
    [ "ppl_Generator_tag", "interfaceppl__Generator__tag.html", "interfaceppl__Generator__tag" ],
    [ "ppl_Grid_Generator_System_const_iterator_tag", "interfaceppl__Grid__Generator__System__const__iterator__tag.html", "interfaceppl__Grid__Generator__System__const__iterator__tag" ],
    [ "ppl_Grid_Generator_System_tag", "interfaceppl__Grid__Generator__System__tag.html", "interfaceppl__Grid__Generator__System__tag" ],
    [ "ppl_Grid_Generator_tag", "interfaceppl__Grid__Generator__tag.html", "interfaceppl__Grid__Generator__tag" ],
    [ "ppl_Linear_Expression_tag", "interfaceppl__Linear__Expression__tag.html", "interfaceppl__Linear__Expression__tag" ],
    [ "ppl_MIP_Problem_tag", "interfaceppl__MIP__Problem__tag.html", "interfaceppl__MIP__Problem__tag" ],
    [ "ppl_PIP_Decision_Node_tag", "interfaceppl__PIP__Decision__Node__tag.html", "interfaceppl__PIP__Decision__Node__tag" ],
    [ "ppl_PIP_Problem_tag", "interfaceppl__PIP__Problem__tag.html", "interfaceppl__PIP__Problem__tag" ],
    [ "ppl_PIP_Solution_Node_tag", "interfaceppl__PIP__Solution__Node__tag.html", "interfaceppl__PIP__Solution__Node__tag" ],
    [ "ppl_PIP_Tree_Node_tag", "interfaceppl__PIP__Tree__Node__tag.html", "interfaceppl__PIP__Tree__Node__tag" ],
    [ "ppl_Pointset_Powerset_C_Polyhedron_const_iterator_tag", "interfaceppl__Pointset__Powerset__C__Polyhedron__const__iterator__tag.html", "interfaceppl__Pointset__Powerset__C__Polyhedron__const__iterator__tag" ],
    [ "ppl_Pointset_Powerset_C_Polyhedron_iterator_tag", "interfaceppl__Pointset__Powerset__C__Polyhedron__iterator__tag.html", "interfaceppl__Pointset__Powerset__C__Polyhedron__iterator__tag" ],
    [ "ppl_Pointset_Powerset_C_Polyhedron_tag", "interfaceppl__Pointset__Powerset__C__Polyhedron__tag.html", "interfaceppl__Pointset__Powerset__C__Polyhedron__tag" ],
    [ "ppl_Polyhedron_tag", "interfaceppl__Polyhedron__tag.html", "interfaceppl__Polyhedron__tag" ]
];

==> ppl_1.1.orig.tar.xz: ppl-user-c-interface-1.1-html/annotated.js <==
var annotated =
[
    [ "Parma_Polyhedra_Library", null, null ],
    [ "ppl_Artificial_Parameter_Sequence_const_iterator_tag", "interfaceppl__Artificial__Parameter__Sequence__const__iterator__tag.html", "interfaceppl__Artificial__Parameter__Sequence__const__iterator__tag" ],
    [ "ppl_Artificial_Parameter_tag", "interfaceppl__Artificial__Parameter__tag.html", "interfaceppl__Artificial__Parameter__tag" ],
    [ "ppl_Coefficient_tag", "interfaceppl__Coefficient__tag.html", "interfaceppl__Coefficient__tag" ],
    [ "ppl_Congruence_System_const_iterator_tag", "interfaceppl__Congruence__System__const__iterator__tag.html", "interfaceppl__Congruence__System__const__iterator__tag" ],
    [ "ppl_Congruence_System_tag", "interfaceppl__Congruence__System__tag.html", "interfaceppl__Congruence__System__tag" ],
    [ "ppl_Congruence_tag", "interfaceppl__Congruence__tag.html", "interfaceppl__Congruence__tag" ],
    [ "ppl_Constraint_System_const_iterator_tag", "interfaceppl__Constraint__System__const__iterator__tag.html", "interfaceppl__Constraint__System__const__iterator__tag" ],
    [ "ppl_Constraint_System_tag", "interfaceppl__Constraint__System__tag.html", "interfaceppl__Constraint__System__tag" ],
    [ "ppl_Constraint_tag", "interfaceppl__Constraint__tag.html", "interfaceppl__Constraint__tag" ],
    [ "ppl_Generator_System_const_iterator_tag", "interfaceppl__Generator__System__const__iterator__tag.html", "interfaceppl__Generator__System__const__iterator__tag" ],
    [ "ppl_Generator_System_tag", "interfaceppl__Generator__System__tag.html", "interfaceppl__Generator__System__tag" ],
    [ "ppl_Generator_tag", "interfaceppl__Generator__tag.html", "interfaceppl__Generator__tag" ],
    [ "ppl_Grid_Generator_System_const_iterator_tag", "interfaceppl__Grid__Generator__System__const__iterator__tag.html", "interfaceppl__Grid__Generator__System__const__iterator__tag" ],
    [ "ppl_Grid_Generator_System_tag", "interfaceppl__Grid__Generator__System__tag.html", "interfaceppl__Grid__Generator__System__tag" ],
    [ "ppl_Grid_Generator_tag", "interfaceppl__Grid__Generator__tag.html", "interfaceppl__Grid__Generator__tag" ],
    [ "ppl_Linear_Expression_tag", "interfaceppl__Linear__Expression__tag.html", "interfaceppl__Linear__Expression__tag" ],
    [ "ppl_MIP_Problem_tag", "interfaceppl__MIP__Problem__tag.html", "interfaceppl__MIP__Problem__tag" ],
    [ "ppl_PIP_Decision_Node_tag", "interfaceppl__PIP__Decision__Node__tag.html", "interfaceppl__PIP__Decision__Node__tag" ],
    [ "ppl_PIP_Problem_tag", "interfaceppl__PIP__Problem__tag.html", "interfaceppl__PIP__Problem__tag" ],
    [ "ppl_PIP_Solution_Node_tag", "interfaceppl__PIP__Solution__Node__tag.html", "interfaceppl__PIP__Solution__Node__tag" ],
    [ "ppl_PIP_Tree_Node_tag", "interfaceppl__PIP__Tree__Node__tag.html", "interfaceppl__PIP__Tree__Node__tag" ],
    [ "ppl_Pointset_Powerset_C_Polyhedron_const_iterator_tag", "interfaceppl__Pointset__Powerset__C__Polyhedron__const__iterator__tag.html", "interfaceppl__Pointset__Powerset__C__Polyhedron__const__iterator__tag" ],
    [ "ppl_Pointset_Powerset_C_Polyhedron_iterator_tag", "interfaceppl__Pointset__Powerset__C__Polyhedron__iterator__tag.html", "interfaceppl__Pointset__Powerset__C__Polyhedron__iterator__tag" ],
    [ "ppl_Pointset_Powerset_C_Polyhedron_tag", "interfaceppl__Pointset__Powerset__C__Polyhedron__tag.html", "interfaceppl__Pointset__Powerset__C__Polyhedron__tag" ],
    [ "ppl_Polyhedron_tag", "interfaceppl__Polyhedron__tag.html", "interfaceppl__Polyhedron__tag" ]
];
